---
nav: All Components
meta:
  title: All Vuetify Components
  description: Browse all of the available Vuetify components or group by category.
  keywords: components, all components, all Vuetify components
---

<script setup>
  import ComponentsListItem from '@/components/components/ListItem.vue'
</script>

# Components

Vuetify Components are interactive building blocks for creating user interfaces.

<entry />

----

## Containment

Containment components wrap other components and provide additional functionality. They are typically used to provide a consistent layout or styling.

<v-row>

<components-list-item name="buttons">

  The button component allows users to take actions or make choices with a single tap

</components-list-item>

<components-list-item name="cards" placeholder>

  The card component is a versatile and enhanced sheet of paper that provides a simple interface for headings, text, images, and actions

</components-list-item>

<components-list-item name="lists">

  The list component is a display interface for items

</components-list-item>

<components-list-item name="chips">

  Chips are useful for displaying small pieces of information

</components-list-item>

<components-list-item name="dividers" placeholder>

  Dividers are used to separate content into distinct sections or groups

</components-list-item>

<components-list-item name="expansion-panels" placeholder>

  Expansion panels are used to reveal additional content in a compact manner

</components-list-item>

<components-list-item name="menus" placeholder>

  The menu component is used to display a list of actions that the user can make

</components-list-item>

<components-list-item name="dialogs" placeholder>

  The dialog component informs a user about a specific task and may contain critical information

</components-list-item>

<components-list-item name="custom-overlays" placeholder>

  The overlay component is used to display a custom scrim that sits on top of the application

</components-list-item>

<components-list-item name="toolbars">

  Toolbars are used to label a content area and / or display a list of actions that the user can make

</components-list-item>

<components-list-item name="tooltips" placeholder>

  Tooltips provide additional information about an element when the user hovers over it

</components-list-item>

<components-list-item name="sheets" placeholder>

  The sheet component is a simple piece of paper that can be used to style and customize a block of content

</components-list-item>

</v-row>

----

## Navigation

Navigation components are used to navigate between different views or pages.

<v-row>

<components-list-item name="app-bars">

  The app bar is used for top level navigation items and current page actions

</components-list-item>

<components-list-item name="navigation-drawers">

  Navigation drawers contain primary application navigation links

</components-list-item>

<components-list-item name="pagination">

  The Pagination component is used to separate long sets of data

</components-list-item>

<components-list-item name="bottom-navigation">

  The bottom navigation component is used for displaying navigation links on mobile

</components-list-item>

<components-list-item name="breadcrumbs">

  Breadcrumbs are navigational helpers for router pages

</components-list-item>

<components-list-item name="footers">

  The footer component is a simple navigation area with inner site links

</components-list-item>

<components-list-item name="system-bars">

  The system bar component shows application information with iconography, time, and more

</components-list-item>

<components-list-item name="tabs" placeholder>

  Tabs are used to organize content into different sections that can be viewed independently

</components-list-item>

</v-row>

----

## Form inputs and controls

Form components are used to collect user input in a variety of ways.

<v-row>

<components-list-item name="autocompletes" placeholder>

  Autocompletes are used to provide suggestions to the user as they type into a field

</components-list-item>

<components-list-item name="comboboxes" placeholder>

  The combobox component is used to select a value from a list of options with the ability to enter a custom value

</components-list-item>

<components-list-item name="text-fields" placeholder>

  The text field component accepts textual input from users and is a replacement for the native text input element

</components-list-item>

<components-list-item name="checkboxes" placeholder>

  The checkbox component is a replacement for the native input checkbox

</components-list-item>

<components-list-item name="switches" placeholder>

  The switch component is an alternately styled checkbox

</components-list-item>

<components-list-item name="radios" placeholder>

  The radio component is a replacement for its native counterpart

</components-list-item>

<components-list-item name="file-inputs" placeholder>

  The file input component is used to select files from the user's device and is a replacement for the native file input element

</components-list-item>

<components-list-item name="forms" placeholder>

  The form component is used to wrap form elements and provide a consistent styling and a single source for validation

</components-list-item>

<components-list-item name="custom-inputs" placeholder>

  Create custom inputs that can be used with the v-model directive

</components-list-item>

<components-list-item name="selects" placeholder>

  The select component is used to select a value from a list of options and is a replacement for the native select element

</components-list-item>

<components-list-item name="sliders" placeholder>

  Sliders are used to select a value from a range of values by moving a slider thumb and are a replacement for the native input range element

</components-list-item>

<components-list-item name="range-sliders" placeholder>

  Range sliders are regular sliders with the ability to select in a range

</components-list-item>

<components-list-item name="textareas" placeholder>

  The textarea component is a replacement for the native textarea element

</components-list-item>

</v-row>

----

## Layouts

Layout components are used to create responsive layouts.

<v-row>

<components-list-item name="grids" placeholder>

  The grid component is used to create responsive layouts

</components-list-item>

</v-row>

----

## Data and display

These components are used to display data and information in a variety of ways.

<v-row>

<components-list-item name="data-tables" placeholder>

  Data tables are used to display large amounts of data in a small amount of space

</components-list-item>

<components-list-item name="server-side-data-tables" placeholder>

  Server side data tables are intended to be used with a server side data source

</components-list-item>

<components-list-item name="virtual-data-tables" placeholder>

  The virtual data table component is used to display very large subsets of data

</components-list-item>

<components-list-item name="tables" placeholder>

  The table component is a barebones table for manually displaying data and is a replacement for the native table element

</components-list-item>

<components-list-item name="virtual-scrollers" placeholder>

  The virtual scroller component makes it possible to render large amounts of data without sacrificing performance

</components-list-item>

</v-row>

----

## Feedback

These components are used to provide feedback to the user within content, over content, or in response to user actions.

<v-row>

<components-list-item name="alerts">

  Alerts convey important information to the user

</components-list-item>

<components-list-item name="badges">

  Badges superscript or subscript an avatar-like icon or text onto content.

</components-list-item>

<components-list-item name="banners">

  Banners are used to communicate important information to the user

</components-list-item>

<components-list-item name="snackbars" placeholder>

  The snackbar component is used to display a message to the user that hovers over existing content

</components-list-item>

<components-list-item name="ratings">

  Ratings are useful for collecting user feedback

</components-list-item>

<components-list-item name="timelines" placeholder>

  Timeline components are used to display a list of events in chronological order

</components-list-item>

<components-list-item name="hover" placeholder>

  The hover component is a wrapper component that allows you to react to hover events

</components-list-item>

<components-list-item name="progress-circular" placeholder>

  Circular progress's are a visual indicator of numerical data in a circle

</components-list-item>

<components-list-item name="progress-linear" placeholder>

  The linear progress component is used to display numerical data in a horizontal line

</components-list-item>

</v-row>

----

## Images and icons

This subset of components are used to display media in a variety of ways.

<v-row>

<components-list-item name="aspect-ratios">

  The aspect ratio component enforces a defined ratio

</components-list-item>

<components-list-item name="avatars">

  Avatars are used in numerous components to display avatars and profile pictures

</components-list-item>

<components-list-item name="icons" placeholder>

  The icon component is an reusable component that can be used to display icons

</components-list-item>

<components-list-item name="images" placeholder>

  The image component provides a flexible interface for displaying images

</components-list-item>

<components-list-item name="parallax" placeholder>

  Creates a 3d effect that makes an image appear to move slower than the foreground

</components-list-item>

</v-row>

----

## Pickers

These components are used to select a value from a specifically styled set of options.

<v-row>

<components-list-item name="color-pickers" placeholder>

  The color picker component is used to select a color from a palette

</components-list-item>

</v-row>

----

## Selection

These components allow a user to select one or multiple items from a list of options.

<v-row>

<components-list-item name="carousels">

  Carousels are used to display multiple forms of visual content

</components-list-item>

<components-list-item name="button-toggles" placeholder>

  Button toggles are used to select between multiple options using the button component

</components-list-item>

<components-list-item name="chip-groups" placeholder>

  Chip group is a wrapper component that makes chips interactive and allows them to be selected

</components-list-item>

<components-list-item name="windows" placeholder>

  The window component is used to display a block of content based upon a model

</components-list-item>

</v-row>

----

## Providers

<v-row>

<components-list-item name="defaults-provider" placeholder>

  The defaults provider component is used to set default values for all components within a template

</components-list-item>

<components-list-item name="locale-providers" placeholder>

  The locale provider component allows you to change the language of all components within its slot

</components-list-item>

<components-list-item name="theme-providers" placeholder>

  The theme provider component allows you to change the theme of all children components

</components-list-item>

</v-row>

----

## Miscellaneous

These components don't fit into a traditional category and are used for a variety of purposes.

<v-row>

<components-list-item name="lazy" placeholder>

  The lazy component is a wrapper component that prevents the rendering of its child components until it is visible in the viewport

</components-list-item>

<components-list-item name="no-ssr" placeholder>

  This component is used to prevent the rendering of its child components on the server

</components-list-item>

</v-row>

<alert type="info">

  This page is under **design** construction and will be updated with the missing images over time.

</alert>
